@@ -3,7 +3,7 @@
 #
 package App::cloc;
 
-our $VERSION = '1.68';
+our $VERSION = '1.76';
 
 1;
 
@@ -13,8 +13,10 @@ App::cloc - Count Lines of Code
 
 =head1 DESCRIPTION
 
-CPAN packaging of the famous L<CLOC|http://cloc.sourceforge.net/> utility, as agreed with its author Al Danial.
-Contains cloc C<v1.68>.
+CPAN packaging of the famous L<CLOC|http://cloc.sourceforge.net/> utility,
+as L<agreed with its author Al Danial|https://github.com/AlDanial/cloc/issues/83>.
+
+Contains cloc C<v1.76>.
 
 =head1 CREATION
 
@@ -23,7 +25,7 @@ In just downloaded latest code and pod from L<cloc repo|https://github.com/AlDan
     wget https://raw.githubusercontent.com/AlDanial/cloc/master/Unix/cloc -O bin/cloc
     wget https://raw.githubusercontent.com/AlDanial/cloc/master/Unix/cloc.1.pod -O - >> bin/cloc
 
-All credits go to Al Danial.
+All credits go to L<Al Danial|https://github.com/AlDanial>.
 
 =head1 LICENSE
 
